@@ -389,9 +389,6 @@ const_bitflag! { HDF: i32;
 	/// [`HDITEM`](crate::HDITEM) `fmt` (`i32`).
 	=>
 	=>
-	/// None of the actual values (zero).
-	NoValue 0
-
 	LEFT 0x0000
 	RIGHT 0x0001
 	CENTER 0x0002
@@ -424,8 +421,7 @@ const_ordinary! { HDFT: u32;
 }
 
 const_bitflag! { HDI: i32;
-	/// [`HDITEM`](crate::HDITEM) and [`NMHDDISPINFO`](crate::NMHDDISPINFO)
-	/// `mask` (`i32`).
+	/// [`HDITEM`](crate::HDITEM) `mask` (`i32`).
 	=>
 	=>
 	WIDTH 0x0001
@@ -492,25 +488,25 @@ const_nm! { HDN;
 	=>
 	FIRST -300
 	=>
-	GETDISPINFO Self::FIRST.0 - 29
-	TRACK Self::FIRST.0 - 28
-	ENDTRACK Self::FIRST.0 - 27
-	BEGINTRACK Self::FIRST.0 - 26
-	DIVIDERDBLCLICK Self::FIRST.0 - 25
-	ITEMDBLCLICK Self::FIRST.0 - 23
-	ITEMCLICK Self::FIRST.0 - 22
-	ITEMCHANGED Self::FIRST.0 - 21
 	ITEMCHANGING Self::FIRST.0 - 20
-	OVERFLOWCLICK Self::FIRST.0 - 19
-	DROPDOWN Self::FIRST.0 - 18
-	ITEMKEYDOWN Self::FIRST.0 - 17
-	ITEMSTATEICONCLICK Self::FIRST.0 - 16
-	ENDFILTEREDIT Self::FIRST.0 - 15
-	BEGINFILTEREDIT Self::FIRST.0 - 14
-	FILTERBTNCLICK Self::FIRST.0 - 13
-	FILTERCHANGE Self::FIRST.0 - 12
-	ENDDRAG Self::FIRST.0 - 11
+	ITEMCHANGED Self::FIRST.0 - 21
+	ITEMCLICK Self::FIRST.0 - 22
+	ITEMDBLCLICK Self::FIRST.0 - 23
+	DIVIDERDBLCLICK Self::FIRST.0 - 25
+	BEGINTRACK Self::FIRST.0 - 26
+	ENDTRACK Self::FIRST.0 - 27
+	TRACK Self::FIRST.0 - 28
+	GETDISPINFO Self::FIRST.0 - 29
 	BEGINDRAG Self::FIRST.0 - 10
+	ENDDRAG Self::FIRST.0 - 11
+	FILTERCHANGE Self::FIRST.0 - 12
+	FILTERBTNCLICK Self::FIRST.0 - 13
+	BEGINFILTEREDIT Self::FIRST.0 - 14
+	ENDFILTEREDIT Self::FIRST.0 - 15
+	ITEMSTATEICONCLICK Self::FIRST.0 - 16
+	ITEMKEYDOWN Self::FIRST.0 - 17
+	DROPDOWN Self::FIRST.0 - 18
+	OVERFLOWCLICK Self::FIRST.0 - 19
 }
 
 const_ws! { HDS: u32;
@@ -2165,8 +2161,9 @@ const_wsex! { TCS_EX;
 }
 
 const_ordinary! { TD_ICON: u16;
-	/// [`HWND::TaskDialog`](crate::prelude::comctl_Hwnd::TaskDialog) `pszIcon`
-	/// and [`IconIdTd`](crate::IconIdTd) `Td` (`u16`).
+	/// [`HWND::TaskDialog`](crate::prelude::comctl_Hwnd::TaskDialog)
+	/// `pszIcon` and [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG)
+	/// `pszMainIcon` (`u16`).
 	///
 	/// Originally has `TD` prefix and `ICON` suffix.
 	=>
@@ -2199,13 +2196,11 @@ const_bitflag! { TDCBF: i32;
 
 const_bitflag! { TDF: i32;
 	/// [`TASKDIALOGCONFIG`](crate::TASKDIALOGCONFIG) `dwFlags` (`i32`).
-	///
-	/// Some constants are set internally, not being publicly available.
 	=>
-	USE_HICON_MAIN 0x0002
-	USE_HICON_FOOTER 0x0004
 	=>
 	ENABLE_HYPERLINKS 0x0001
+	USE_HICON_MAIN 0x0002
+	USE_HICON_FOOTER 0x0004
 	ALLOW_DIALOG_CANCELLATION 0x0008
 	USE_COMMAND_LINKS 0x0010
 	USE_COMMAND_LINKS_NO_ICON 0x0020
